@@ -9,13 +9,13 @@ from csvkit.cli import CSVFileType, CSVKitUtility
 
 class CSVSQL(CSVKitUtility):
     description = 'Generate SQL statements for a CSV file or create execute those statements directly on a database.'
-    override_flags = 'lf'
+    override_flags = ['l', 'f']
 
     def add_arguments(self):
         self.argparser.add_argument('files', metavar="FILE", nargs='*', type=CSVFileType(), default=sys.stdin,
             help='The CSV file(s) to operate on. If omitted, will accept input on STDIN.')
         self.argparser.add_argument('-y', '--snifflimit', dest='snifflimit', type=int,
-            help='Limit CSV dialect sniffing to the specified number of bytes.')
+            help='Limit CSV dialect sniffing to the specified number of bytes. Specify "0" to disable sniffing entirely.')
         self.argparser.add_argument('-i', '--dialect', dest='dialect', choices=sql.DIALECTS,
             help='Dialect of SQL to generate. Only valid when --db is not specified.')
         self.argparser.add_argument('--db', dest='connection_string',
@@ -30,16 +30,14 @@ class CSVSQL(CSVKitUtility):
             help='Skip creating a table. Only valid when --insert is specified.')
         self.argparser.add_argument('--blanks', dest='blanks', action='store_true',
             help='Do not coerce empty strings to NULL values.')
-        self.argparser.add_argument('--no-infer', dest='no_infer',
-            help='A comma separated list of column indices or names to skip type inference. Specified columns will be treated as strings.')
+        self.argparser.add_argument('--no-inference', dest='no_inference', action='store_true',
+            help='Disable type inference when parsing the input.')
+        self.argparser.add_argument('--db-schema', dest='db_schema',
+            help='Optional name of database schema to create table(s) in.')
 
     def main(self):
-        # Ensure we're handling a list, even if it's just one file
-        if not isinstance(self.args.files, list):
-            self.args.files = [self.args.files]
-        else:
-            if self.args.table_name:
-                self.argparser.error('The --table argument is only allowed when specifying a single file.')
+        if len(self.args.files) > 1 and self.args.table_name:
+            self.argparser.error('The --table argument is only allowed when specifying a single file.')
 
         for f in self.args.files:
             if self.args.table_name:
@@ -59,7 +57,15 @@ class CSVSQL(CSVKitUtility):
             if self.args.no_create and not self.args.insert:
                 self.argparser.error('The --no-create option is only valid --insert is also specified.')
 
-            csv_table = table.Table.from_csv(f, name=table_name, snifflimit=self.args.snifflimit, blanks_as_nulls=(not self.args.blanks), **self.reader_kwargs)
+            csv_table = table.Table.from_csv(
+                f,
+                name=table_name,
+                snifflimit=self.args.snifflimit,
+                blanks_as_nulls=(not self.args.blanks),
+                infer_types=(not self.args.no_inference),
+                no_header_row=self.args.no_header_row,
+                **self.reader_kwargs
+            )
 
             f.close()
 
@@ -70,7 +76,13 @@ class CSVSQL(CSVKitUtility):
                 except ImportError:
                     raise ImportError('You don\'t appear to have the necessary database backend installed for connection string you\'re trying to use.. Available backends include:\n\nPostgresql:\tpip install psycopg2\nMySQL:\t\tpip install MySQL-python\n\nFor details on connection strings and other backends, please see the SQLAlchemy documentation on dialects at: \n\nhttp://www.sqlalchemy.org/docs/dialects/\n\n')
 
-                sql_table = sql.make_table(csv_table, table_name, self.args.no_constraints, metadata)
+                sql_table = sql.make_table(
+                    csv_table,
+                    table_name,
+                    self.args.no_constraints,
+                    self.args.db_schema,
+                    metadata
+                )
 
                 if not self.args.no_create:
                     sql_table.create()
@@ -81,8 +93,7 @@ class CSVSQL(CSVKitUtility):
 
                     conn = engine.connect()
                     trans = conn.begin()
-                    for row in csv_table.to_rows():
-                        conn.execute(insert, [dict(zip(headers, row)), ])
+                    conn.execute(insert, [dict(zip(headers, row)) for row in csv_table.to_rows()])
                     trans.commit()
                     conn.close()
 
