@@ -8,7 +8,7 @@ from csvkit.cli import CSVFileType, CSVKitUtility
 class In2CSV(CSVKitUtility):
     description = 'Convert common, but less awesome, tabular data formats to CSV.'
     epilog='Some command line flags only pertain to specific input formats.'
-    override_flags = 'f'
+    override_flags = ['f']
 
     def add_arguments(self):
         self.argparser.add_argument('file', metavar="FILE", nargs='?', default=sys.stdin,
@@ -20,7 +20,11 @@ class In2CSV(CSVKitUtility):
         self.argparser.add_argument('-k', '--key', dest='key',
                             help='Specifies a top-level key to use look within for a list of objects to be converted when processing JSON.')
         self.argparser.add_argument('-y', '--snifflimit', dest='snifflimit', type=int,
-                            help='Limit CSV dialect sniffing to the specified number of bytes.')
+                            help='Limit CSV dialect sniffing to the specified number of bytes. Specify "0" to disable sniffing entirely.')
+        self.argparser.add_argument('--sheet', dest='sheet',
+                            help='The name of the XLSX sheet to operate on.')
+        self.argparser.add_argument('--no-inference', dest='no_inference', action='store_true',
+                            help='Disable type inference when parsing the input.')
 
 
     def main(self):
@@ -61,6 +65,15 @@ class In2CSV(CSVKitUtility):
         if self.args.snifflimit:
             kwargs['snifflimit'] = self.args.snifflimit
 
+        if self.args.sheet:
+            kwargs['sheet'] = self.args.sheet
+
+        if self.args.no_inference:
+            kwargs['type_inference'] = False
+
+        if format == 'csv' and self.args.no_header_row:
+            kwargs['no_header_row'] = True
+
         # Fixed width can be processed as a stream
         if format == 'fixed':
             kwargs['output'] = self.output_file
